==> rapid_widgets_library-0.2.42.tar.gz: lib/feedbackform.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'Dialogs.dart';
import 'package:http/http.dart' as http;
class ReachUs extends StatefulWidget {
  final FeedBackForm feedBackForm;

  ReachUs({this.feedBackForm});
  @override
  _ReachUsState createState() => _ReachUsState();
}
class _ReachUsState extends State<ReachUs> {
  launchUrl(String url) async {
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }
  _launchURLMail() async {
    const url =
        'mailto:example@example.org?subject=LowCodeNocode&body=Your sugestions%20or Feedback..';
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }

  TextEditingController t1 = TextEditingController();
  TextEditingController t2 = TextEditingController();
  String name;
  String message;
  double _rating =2.0;
  double _initialRating = 2.0;
  bool _isVertical = false;
  var _formKey = GlobalKey<FormState>();
  final GlobalKey<State> _keyLoader = new GlobalKey<State>();

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(10.0),
      child: SingleChildScrollView(
        child: Form(
          key: _formKey,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            children: <Widget>[
              Padding(
                padding:
                const EdgeInsets.symmetric(vertical: 14.0, horizontal: 13),
                child: Text(
                  "Leave us a Feedback",
                  style: TextStyle(
                    fontSize: 17.5,
                    height: 1.3,
                    fontFamily: 'RobotoSlab',
                  ),
                  textAlign: TextAlign.justify,
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.02,
              ),
              Padding(
                padding: const EdgeInsets.all(10.0),
                child: TextFormField(
                  validator: (text) {
                    if (text == null ||  text.trim().isEmpty) {
                      return 'Name is required';
                    }
                    return null;
                  },
                  onChanged: (val) {
                    if (val != null || val.length > 0) name = val;
                  },
                  controller: t1,
                  decoration: InputDecoration(
                    hintText: 'Your name',
                    hintStyle: TextStyle(
                        color: Colors.blueGrey, fontFamily: 'RobotoSlab'),
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.all(
                        Radius.circular(10),
                      ),
                      borderSide: BorderSide(color: Colors.grey),
                    ),

                  ),
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.0001,
              ),
              Padding(
                padding: const EdgeInsets.all(10),
                child: TextFormField(
                  validator: (text) {
                    if (text == null || text.trim().isEmpty) {
                      return 'Message is required';
                    }
                    return null;
                  },
                  onChanged: (val) {
                    if (val != null || val.length > 0) message = val;
                  },
                  textAlign: TextAlign.start,
                  controller: t2,
                  decoration: InputDecoration(
                    hintText: 'Your message',
                    hintStyle: TextStyle(
                      color: Colors.blueGrey,
                      fontFamily: 'RobotoSlab',
                    ),
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.all(
                        Radius.circular(10),
                      ),
                      borderSide: BorderSide(color: Colors.grey),
                    ),
                  ),
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.03,
              ),
              Padding(
                padding: const EdgeInsets.only(left: 15.0),
                child: Container(
                  alignment: Alignment.centerLeft,
                  child: Text(
                    'Overall Rating : $_rating',
                    style: TextStyle(fontWeight: FontWeight.bold,color:  Colors.grey),
                  ),
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: Container(
                  alignment: Alignment.centerLeft,
                  child: widget.feedBackForm.rattingBarType =='Star'?
                  RatingBar.builder(
                    initialRating: _initialRating,
                    minRating: 1,
                    direction: _isVertical ? Axis.vertical : Axis.horizontal,
                    allowHalfRating: true,
                    unratedColor: widget.feedBackForm.rattingBarStarColor.withAlpha(50),
                    itemCount: 5,
                    itemSize: 30.0,
                    itemPadding: EdgeInsets.symmetric(horizontal: 4.0),
                    itemBuilder: (context, _) => Icon(
                      Icons.star,
                      color: widget.feedBackForm.rattingBarStarColor,
                    ),
                    onRatingUpdate: (rating) {
                      setState(() {
                        _rating = rating;
                      });
                    },
                    updateOnDrag: true,
                  ):
                  RatingBar.builder(
                    initialRating: _initialRating,
                    direction: _isVertical ? Axis.vertical : Axis.horizontal,
                    itemCount: 5,
                    itemPadding: EdgeInsets.symmetric(horizontal: 4.0),
                    itemBuilder: (context, index) {
                      switch (index) {
                        case 0:
                          return Icon(
                            Icons.sentiment_very_dissatisfied,
                            color: Colors.red,
                          );
                        case 1:
                          return Icon(
                            Icons.sentiment_dissatisfied,
                            color: Colors.redAccent,
                          );
                        case 2:
                          return Icon(
                            Icons.sentiment_neutral,
                            color: Colors.amber,
                          );
                        case 3:
                          return Icon(
                            Icons.sentiment_satisfied,
                            color: Colors.lightGreen,
                          );
                        case 4:
                          return Icon(
                            Icons.sentiment_very_satisfied,
                            color: Colors.green,
                          );
                        default:
                          return Container();
                      }
                    },
                    onRatingUpdate: (rating) {
                      setState(() {
                        _rating = rating;
                      });
                    },
                    updateOnDrag: true,
                  ),
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.003,
              ),

              ElevatedButton.icon(
                style:  ElevatedButton.styleFrom(
                  primary:widget.feedBackForm.submitButtonColor,
                ),
                onPressed: () {
                  final isValid = _formKey.currentState.validate();
                  if (!isValid) {
                    return;
                  }
                  fetchDataFromAPI();
                  Dialogs.showLoadingDialog(
                      context: context,
                      key: _keyLoader,
                      backgroundColor: widget.feedBackForm.dialogBackgroundColor,
                      progressTextColor: widget.feedBackForm.dialogIndiactorTextColor,
                      msg:  widget.feedBackForm.dialogMessage
                  );
                  setState(() {
                    t1.clear();
                    t2.clear();
                  });
                },
                icon: Icon(
                  Icons.send,
                  color: widget.feedBackForm.sendIconColor,
                  size: 17,
                ), label: Text('Send',style: TextStyle(color:  widget.feedBackForm.sendIconColor),),
              ),
              /* SizedBox(
                  height: 15,
                ),*/
              Padding(
                padding: EdgeInsets.only(
                    top: 20,
                    left: 21,
                    right: 21,
                    bottom: MediaQuery.of(context).size.height * 0.034),
                child: Text(
                  "Alternatively, you can reach out to us on the following platforms",
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    fontFamily: 'RobotoSlab',
                    color: Colors.blueGrey[600],
                    fontSize: 17,
                    height: 1.3,
                  ),
                ),
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  GestureDetector(
                    onTap: () => launchUrl(
                        (widget.feedBackForm.twitterUrl!='null')?widget.feedBackForm.twitterUrl:"https://twitter.com/"),
                    child: Icon(
                      FontAwesomeIcons.twitter,
                      color: Colors.lightBlueAccent,
                      size: 30,
                    ),
                  ),
                  SizedBox(
                    width: MediaQuery.of(context).size.width * 0.06,
                  ),
                  GestureDetector(
                    onTap: () => launchUrl(
                        (widget.feedBackForm.facebookUrl!='null')?widget.feedBackForm.facebookUrl:"https://www.facebook.com/"),
                    child: Icon(FontAwesomeIcons.facebook,
                        color: Colors.blue, size: 30),
                  ),
                  SizedBox(
                    width: MediaQuery.of(context).size.width * 0.06,
                  ),
                  GestureDetector(
                    onTap: () => launchUrl(
                        (widget.feedBackForm.instaUrl!='null')?widget.feedBackForm.instaUrl:"https://www.instagram.com/"),
                    child: Icon(FontAwesomeIcons.instagram,
                        color: Colors.pinkAccent, size: 30),
                  ),
                ],
              ),
            ],
          ),
        ),
      ),

    );
  }
  fetchDataFromAPI() async {
    final response1 = await http.post(
      Uri.parse(widget.feedBackForm.postUrl!='null'?widget.feedBackForm.postUrl:'http://40.121.135.8:9818/test/url'),
      headers: <String, String>{
        'Content-Type': 'application/json; charset=UTF-8',
      },
      body: jsonEncode(<String, String>{
        'title': 'FeedBack',
        'name': t1.text,
        'message':t2.text,
        'ratting':_rating.toString()
      }),
    );
    print("statusCode"+response1.statusCode.toString());
    print("headers"+response1.headers.toString());
    print("body"+response1.body.toString());

    /*final response =
    await http.get(Uri.parse(api)); //(API_URL+'processAPILink?api=" + api);
    if (response.statusCode == 200) {
      return json.decode(response.body);
    }*/
    /* if (response1.statusCode == 201) {
      print(response1.body.toString());
      return json.decode(response1.body);
    }*/
  }
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/feedbackform.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'Dialogs.dart';
import 'package:http/http.dart' as http;
class ReachUs extends StatefulWidget {
  final FeedBackForm feedBackForm;

  ReachUs({this.feedBackForm});
  @override
  _ReachUsState createState() => _ReachUsState();
}
class _ReachUsState extends State<ReachUs> {
  launchUrl(String url) async {
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }
  _launchURLMail() async {
    const url =
        'mailto:example@example.org?subject=LowCodeNocode&body=Your sugestions%20or Feedback..';
    if (await canLaunch(url)) {
      await launch(url);
    } else {
      throw 'Could not launch $url';
    }
  }

  TextEditingController t1 = TextEditingController();
  TextEditingController t2 = TextEditingController();
  String name;
  String message;
  double _rating =2.0;
  double _initialRating = 2.0;
  bool _isVertical = false;
  var _formKey = GlobalKey<FormState>();
  final GlobalKey<State> _keyLoader = new GlobalKey<State>();

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(10.0),
      child: SingleChildScrollView(
        child: Form(
          key: _formKey,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.start,
            children: <Widget>[
              Padding(
                padding:
                const EdgeInsets.symmetric(vertical: 14.0, horizontal: 13),
                child: Text(
                  "Leave us a Feedback",
                  style: GoogleFonts.getFont('Roboto',
                    fontSize: 17.5,
                    height: 1.3,
                  ),
                  textAlign: TextAlign.justify,
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.02,
              ),
              Padding(
                padding: const EdgeInsets.all(10.0),
                child: TextFormField(
                  validator: (text) {
                    if (text == null ||  text.trim().isEmpty) {
                      return 'Name is required';
                    }
                    return null;
                  },
                  onChanged: (val) {
                    if (val != null || val.length > 0) name = val;
                  },
                  controller: t1,
                  decoration: InputDecoration(
                    hintText: 'Your name',
                    hintStyle: GoogleFonts.getFont('Roboto',
                        color: Colors.blueGrey),
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.all(
                        Radius.circular(10),
                      ),
                      borderSide: BorderSide(color: Colors.grey),
                    ),

                  ),
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.0001,
              ),
              Padding(
                padding: const EdgeInsets.all(10),
                child: TextFormField(
                  validator: (text) {
                    if (text == null || text.trim().isEmpty) {
                      return 'Message is required';
                    }
                    return null;
                  },
                  onChanged: (val) {
                    if (val != null || val.length > 0) message = val;
                  },
                  textAlign: TextAlign.start,
                  controller: t2,
                  decoration: InputDecoration(
                    hintText: 'Your message',
                    hintStyle: GoogleFonts.getFont('Roboto',
                      color: Colors.blueGrey,
                    ),
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.all(
                        Radius.circular(10),
                      ),
                      borderSide: BorderSide(color: Colors.grey),
                    ),
                  ),
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.03,
              ),
              Padding(
                padding: const EdgeInsets.only(left: 15.0),
                child: Container(
                  alignment: Alignment.centerLeft,
                  child: Text(
                    'Overall Rating : $_rating',
                    style: GoogleFonts.getFont('Roboto',fontWeight: FontWeight.bold,color:  Colors.grey),
                  ),
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: Container(
                  alignment: Alignment.centerLeft,
                  child: widget.feedBackForm.rattingBarType =='Star'?
                  RatingBar.builder(
                    initialRating: _initialRating,
                    minRating: 1,
                    direction: _isVertical ? Axis.vertical : Axis.horizontal,
                    allowHalfRating: true,
                    unratedColor: widget.feedBackForm.rattingBarStarColor.withAlpha(50),
                    itemCount: 5,
                    itemSize: 30.0,
                    itemPadding: EdgeInsets.symmetric(horizontal: 4.0),
                    itemBuilder: (context, _) => Icon(
                      Icons.star,
                      color: widget.feedBackForm.rattingBarStarColor,
                    ),
                    onRatingUpdate: (rating) {
                      setState(() {
                        _rating = rating;
                      });
                    },
                    updateOnDrag: true,
                  ):
                  RatingBar.builder(
                    initialRating: _initialRating,
                    direction: _isVertical ? Axis.vertical : Axis.horizontal,
                    itemCount: 5,
                    itemPadding: EdgeInsets.symmetric(horizontal: 4.0),
                    itemBuilder: (context, index) {
                      switch (index) {
                        case 0:
                          return Icon(
                            Icons.sentiment_very_dissatisfied,
                            color: Colors.red,
                          );
                        case 1:
                          return Icon(
                            Icons.sentiment_dissatisfied,
                            color: Colors.redAccent,
                          );
                        case 2:
                          return Icon(
                            Icons.sentiment_neutral,
                            color: Colors.amber,
                          );
                        case 3:
                          return Icon(
                            Icons.sentiment_satisfied,
                            color: Colors.lightGreen,
                          );
                        case 4:
                          return Icon(
                            Icons.sentiment_very_satisfied,
                            color: Colors.green,
                          );
                        default:
                          return Container();
                      }
                    },
                    onRatingUpdate: (rating) {
                      setState(() {
                        _rating = rating;
                      });
                    },
                    updateOnDrag: true,
                  ),
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.003,
              ),

              ElevatedButton.icon(
                style:  ElevatedButton.styleFrom(
                  primary:widget.feedBackForm.submitButtonColor,
                ),
                onPressed: () {
                  final isValid = _formKey.currentState.validate();
                  if (!isValid) {
                    return;
                  }
                  fetchDataFromAPI();
                  Dialogs.showLoadingDialog(
                      context: context,
                      key: _keyLoader,
                      backgroundColor: widget.feedBackForm.dialogBackgroundColor,
                      progressTextColor: widget.feedBackForm.dialogIndiactorTextColor,
                      msg:  widget.feedBackForm.dialogMessage
                  );
                  (widget.feedBackForm.onclick!=null)?widget.feedBackForm.onclick:(){};
                  setState(() {
                    t1.clear();
                    t2.clear();
                  });
                },
                icon: Icon(
                  Icons.send,
                  color: widget.feedBackForm.sendIconColor,
                  size: 17,
                ), label: Text('Send',style: GoogleFonts.getFont('Roboto',color:  widget.feedBackForm.sendIconColor),),
              ),
              /* SizedBox(
                  height: 15,
                ),*/
              Padding(
                padding: EdgeInsets.only(
                    top: 20,
                    left: 21,
                    right: 21,
                    bottom: MediaQuery.of(context).size.height * 0.034),
                child: Text(
                  "Alternatively, you can reach out to us on the following platforms",
                  textAlign: TextAlign.center,
                  style: GoogleFonts.getFont('Roboto',
                    color: Colors.blueGrey[600],
                    fontSize: 17,
                    height: 1.3,
                  ),
                ),
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  GestureDetector(
                    onTap: () => launchUrl(
                        (widget.feedBackForm.twitterUrl!='null')?widget.feedBackForm.twitterUrl:"https://twitter.com/"),
                    child: Icon(
                      FontAwesomeIcons.twitter,
                      color: Colors.lightBlueAccent,
                      size: 30,
                    ),
                  ),
                  SizedBox(
                    width: MediaQuery.of(context).size.width * 0.06,
                  ),
                  GestureDetector(
                    onTap: () => launchUrl(
                        (widget.feedBackForm.facebookUrl!='null')?widget.feedBackForm.facebookUrl:"https://www.facebook.com/"),
                    child: Icon(FontAwesomeIcons.facebook,
                        color: Colors.blue, size: 30),
                  ),
                  SizedBox(
                    width: MediaQuery.of(context).size.width * 0.06,
                  ),
                  GestureDetector(
                    onTap: () => launchUrl(
                        (widget.feedBackForm.instaUrl!='null')?widget.feedBackForm.instaUrl:"https://www.instagram.com/"),
                    child: Icon(FontAwesomeIcons.instagram,
                        color: Colors.pinkAccent, size: 30),
                  ),
                ],
              ),
            ],
          ),
        ),
      ),

    );
  }
  fetchDataFromAPI() async {
    final response1 = await http.post(
      Uri.parse(widget.feedBackForm.postUrl!='null'?widget.feedBackForm.postUrl:'http://40.121.135.8:9818/test/url'),
      headers: <String, String>{
        'Content-Type': 'application/json; charset=UTF-8',
      },
      body: jsonEncode(<String, String>{
        'title': 'FeedBack',
        'name': t1.text,
        'message':t2.text,
        'ratting':_rating.toString()
      }),
    );
    print("statusCode"+response1.statusCode.toString());
    print("headers"+response1.headers.toString());
    print("body"+response1.body.toString());

  }
}
